Class: Aws::SNS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SNS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sns/client.rb,
sig/client.rbs
Overview
An API client for SNS. To construct a client, you need to configure a :region and :credentials.
client = Aws::SNS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CheckIfPhoneNumberIsOptedOutResponseSuccess, _ConfirmSubscriptionResponseSuccess, _CreatePlatformApplicationResponseSuccess, _CreatePlatformEndpointResponseSuccess, _CreateSMSSandboxPhoneNumberResponseSuccess, _CreateTopicResponseSuccess, _DeleteSMSSandboxPhoneNumberResponseSuccess, _GetDataProtectionPolicyResponseSuccess, _GetEndpointAttributesResponseSuccess, _GetPlatformApplicationAttributesResponseSuccess, _GetSMSAttributesResponseSuccess, _GetSMSSandboxAccountStatusResponseSuccess, _GetSubscriptionAttributesResponseSuccess, _GetTopicAttributesResponseSuccess, _ListEndpointsByPlatformApplicationResponseSuccess, _ListOriginationNumbersResponseSuccess, _ListPhoneNumbersOptedOutResponseSuccess, _ListPlatformApplicationsResponseSuccess, _ListSMSSandboxPhoneNumbersResponseSuccess, _ListSubscriptionsByTopicResponseSuccess, _ListSubscriptionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTopicsResponseSuccess, _OptInPhoneNumberResponseSuccess, _PublishBatchResponseSuccess, _PublishResponseSuccess, _SetSMSAttributesResponseSuccess, _SubscribeResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _VerifySMSSandboxPhoneNumberResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_permission(params = {}) ⇒ Struct
Adds a statement to a topic's access control policy, granting access for the specified Amazon Web Services accounts to the specified actions.
-
#check_if_phone_number_is_opted_out(params = {}) ⇒ Types::CheckIfPhoneNumberIsOptedOutResponse
Accepts a phone number and indicates whether the phone holder has opted out of receiving SMS messages from your Amazon Web Services account.
-
#confirm_subscription(params = {}) ⇒ Types::ConfirmSubscriptionResponse
Verifies an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier
Subscribeaction. -
#create_platform_application(params = {}) ⇒ Types::CreatePlatformApplicationResponse
Creates a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging), to which devices and mobile apps may register.
-
#create_platform_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates an endpoint for a device and mobile app on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS.
-
#create_sms_sandbox_phone_number(params = {}) ⇒ Struct
Adds a destination phone number to an Amazon Web Services account in the SMS sandbox and sends a one-time password (OTP) to that phone number.
-
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic to which notifications can be published.
-
#delete_endpoint(params = {}) ⇒ Struct
Deletes the endpoint for a device and mobile app from Amazon SNS.
-
#delete_platform_application(params = {}) ⇒ Struct
Deletes a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging).
-
#delete_sms_sandbox_phone_number(params = {}) ⇒ Struct
Deletes an Amazon Web Services account's verified or pending phone number from the SMS sandbox.
-
#delete_topic(params = {}) ⇒ Struct
Deletes a topic and all its subscriptions.
-
#get_data_protection_policy(params = {}) ⇒ Types::GetDataProtectionPolicyResponse
Retrieves the specified inline
DataProtectionPolicydocument that is stored in the specified Amazon SNS topic. -
#get_endpoint_attributes(params = {}) ⇒ Types::GetEndpointAttributesResponse
Retrieves the endpoint attributes for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS.
-
#get_platform_application_attributes(params = {}) ⇒ Types::GetPlatformApplicationAttributesResponse
Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging).
-
#get_sms_attributes(params = {}) ⇒ Types::GetSMSAttributesResponse
Returns the settings for sending SMS messages from your Amazon Web Services account.
-
#get_sms_sandbox_account_status(params = {}) ⇒ Types::GetSMSSandboxAccountStatusResult
Retrieves the SMS sandbox status for the calling Amazon Web Services account in the target Amazon Web Services Region.
-
#get_subscription_attributes(params = {}) ⇒ Types::GetSubscriptionAttributesResponse
Returns all of the properties of a subscription.
-
#get_topic_attributes(params = {}) ⇒ Types::GetTopicAttributesResponse
Returns all of the properties of a topic.
-
#list_endpoints_by_platform_application(params = {}) ⇒ Types::ListEndpointsByPlatformApplicationResponse
Lists the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM (Firebase Cloud Messaging) and APNS.
-
#list_origination_numbers(params = {}) ⇒ Types::ListOriginationNumbersResult
Lists the calling Amazon Web Services account's dedicated origination numbers and their metadata.
-
#list_phone_numbers_opted_out(params = {}) ⇒ Types::ListPhoneNumbersOptedOutResponse
Returns a list of phone numbers that are opted out, meaning you cannot send SMS messages to them.
-
#list_platform_applications(params = {}) ⇒ Types::ListPlatformApplicationsResponse
Lists the platform application objects for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging).
-
#list_sms_sandbox_phone_numbers(params = {}) ⇒ Types::ListSMSSandboxPhoneNumbersResult
Lists the calling Amazon Web Services account's current verified and pending destination phone numbers in the SMS sandbox.
-
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Returns a list of the requester's subscriptions.
-
#list_subscriptions_by_topic(params = {}) ⇒ Types::ListSubscriptionsByTopicResponse
Returns a list of the subscriptions to a specific topic.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags added to the specified Amazon SNS topic.
-
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
Returns a list of the requester's topics.
-
#opt_in_phone_number(params = {}) ⇒ Struct
Use this request to opt in a phone number that is opted out, which enables you to resume sending SMS messages to the number.
-
#publish(params = {}) ⇒ Types::PublishResponse
Sends a message to an Amazon SNS topic, a text message (SMS message) directly to a phone number, or a message to a mobile platform endpoint (when you specify the
TargetArn). -
#publish_batch(params = {}) ⇒ Types::PublishBatchResponse
Publishes up to 10 messages to the specified topic in a single batch.
-
#put_data_protection_policy(params = {}) ⇒ Struct
Adds or updates an inline policy document that is stored in the specified Amazon SNS topic.
-
#remove_permission(params = {}) ⇒ Struct
Removes a statement from a topic's access control policy.
-
#set_endpoint_attributes(params = {}) ⇒ Struct
Sets the attributes for an endpoint for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS.
-
#set_platform_application_attributes(params = {}) ⇒ Struct
Sets the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging).
-
#set_sms_attributes(params = {}) ⇒ Struct
Use this request to set the default settings for sending SMS messages and receiving daily SMS usage reports.
-
#set_subscription_attributes(params = {}) ⇒ Struct
Allows a subscription owner to set an attribute of the subscription to a new value.
-
#set_topic_attributes(params = {}) ⇒ Struct
Allows a topic owner to set an attribute of the topic to a new value.
-
#subscribe(params = {}) ⇒ Types::SubscribeResponse
Subscribes an endpoint to an Amazon SNS topic.
-
#tag_resource(params = {}) ⇒ Struct
Add tags to the specified Amazon SNS topic.
-
#unsubscribe(params = {}) ⇒ Struct
Deletes a subscription.
-
#untag_resource(params = {}) ⇒ Struct
Remove tags from the specified Amazon SNS topic.
-
#verify_sms_sandbox_phone_number(params = {}) ⇒ Struct
Verifies a destination phone number with a one-time password (OTP) for the calling Amazon Web Services account.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-sns/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3185 3186 3187 |
# File 'lib/aws-sdk-sns/client.rb', line 3185 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3188 3189 3190 |
# File 'lib/aws-sdk-sns/client.rb', line 3188 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_permission(params = {}) ⇒ Struct
Adds a statement to a topic's access control policy, granting access for the specified Amazon Web Services accounts to the specified actions.
AddPermission, RemovePermission, and
SetTopicAttributes actions in your IAM policy.
82 |
# File 'sig/client.rbs', line 82
def add_permission: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 3169 3170 3171 3172 3173 3174 |
# File 'lib/aws-sdk-sns/client.rb', line 3158 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SNS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sns' context[:gem_version] = '1.118.0' Seahorse::Client::Request.new(handlers, context) end |
#check_if_phone_number_is_opted_out(params = {}) ⇒ Types::CheckIfPhoneNumberIsOptedOutResponse
Accepts a phone number and indicates whether the phone holder has opted out of receiving SMS messages from your Amazon Web Services account. You cannot send SMS messages to a number that is opted out.
To resume sending messages, you can opt in the number by using the
OptInPhoneNumber action.
95 |
# File 'sig/client.rbs', line 95
def check_if_phone_number_is_opted_out: (
|
#confirm_subscription(params = {}) ⇒ Types::ConfirmSubscriptionResponse
Verifies an endpoint owner's intent to receive messages by validating
the token sent to the endpoint by an earlier Subscribe action. If
the token is valid, the action creates a new subscription and returns
its Amazon Resource Name (ARN). This call requires an AWS signature
only when the AuthenticateOnUnsubscribe flag is set to "true".
105 |
# File 'sig/client.rbs', line 105
def confirm_subscription: (
|
#create_platform_application(params = {}) ⇒ Types::CreatePlatformApplicationResponse
Creates a platform application object for one of the supported push
notification services, such as APNS and GCM (Firebase Cloud
Messaging), to which devices and mobile apps may register. You must
specify PlatformPrincipal and PlatformCredential attributes when
using the CreatePlatformApplication action.
PlatformPrincipal and PlatformCredential are received from the
notification service.
-
For ADM,
PlatformPrincipalisclient idandPlatformCredentialisclient secret. -
For APNS and
APNS_SANDBOXusing certificate credentials,PlatformPrincipalisSSL certificateandPlatformCredentialisprivate key. -
For APNS and
APNS_SANDBOXusing token credentials,PlatformPrincipalissigning key IDandPlatformCredentialissigning key. -
For Baidu,
PlatformPrincipalisAPI keyandPlatformCredentialissecret key. -
For GCM (Firebase Cloud Messaging) using key credentials, there is no
PlatformPrincipal. ThePlatformCredentialisAPI key. -
For GCM (Firebase Cloud Messaging) using token credentials, there is no
PlatformPrincipal. ThePlatformCredentialis a JSON formatted private key file. When using the Amazon Web Services CLI or Amazon Web Services SDKs, the file must be in string format and special characters must be ignored. To format the file correctly, Amazon SNS recommends using the following command:SERVICE_JSON=$(jq @json < service.json). -
For MPNS,
PlatformPrincipalisTLS certificateandPlatformCredentialisprivate key. -
For WNS,
PlatformPrincipalisPackage Security IdentifierandPlatformCredentialissecret key.
You can use the returned PlatformApplicationArn as an attribute for
the CreatePlatformEndpoint action.
117 |
# File 'sig/client.rbs', line 117
def create_platform_application: (
|
#create_platform_endpoint(params = {}) ⇒ Types::CreateEndpointResponse
Creates an endpoint for a device and mobile app on one of the
supported push notification services, such as GCM (Firebase Cloud
Messaging) and APNS. CreatePlatformEndpoint requires the
PlatformApplicationArn that is returned from
CreatePlatformApplication. You can use the returned EndpointArn to
send a message to a mobile app or by the Subscribe action for
subscription to a topic. The CreatePlatformEndpoint action is
idempotent, so if the requester already owns an endpoint with the same
device token and attributes, that endpoint's ARN is returned without
creating a new endpoint. For more information, see Using Amazon SNS
Mobile Push Notifications.
When using CreatePlatformEndpoint with Baidu, two attributes must be
provided: ChannelId and UserId. The token field must also contain the
ChannelId. For more information, see Creating an Amazon SNS Endpoint
for Baidu.
129 |
# File 'sig/client.rbs', line 129
def create_platform_endpoint: (
|
#create_sms_sandbox_phone_number(params = {}) ⇒ Struct
Adds a destination phone number to an Amazon Web Services account in the SMS sandbox and sends a one-time password (OTP) to that phone number.
When you start using Amazon SNS to send SMS messages, your Amazon Web Services account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your Amazon Web Services account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.
141 |
# File 'sig/client.rbs', line 141
def create_sms_sandbox_phone_number: (
|
#create_topic(params = {}) ⇒ Types::CreateTopicResponse
Creates a topic to which notifications can be published. Users can create at most 100,000 standard topics (at most 1,000 FIFO topics). For more information, see Creating an Amazon SNS topic in the Amazon SNS Developer Guide. This action is idempotent, so if the requester already owns a topic with the specified name, that topic's ARN is returned without creating a new topic.
152 |
# File 'sig/client.rbs', line 152
def create_topic: (
|
#delete_endpoint(params = {}) ⇒ Struct
Deletes the endpoint for a device and mobile app from Amazon SNS. This action is idempotent. For more information, see Using Amazon SNS Mobile Push Notifications.
When you delete an endpoint that is also subscribed to a topic, then you must also unsubscribe the endpoint from the topic.
166 |
# File 'sig/client.rbs', line 166
def delete_endpoint: (
|
#delete_platform_application(params = {}) ⇒ Struct
Deletes a platform application object for one of the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications.
172 |
# File 'sig/client.rbs', line 172
def delete_platform_application: (
|
#delete_sms_sandbox_phone_number(params = {}) ⇒ Struct
Deletes an Amazon Web Services account's verified or pending phone number from the SMS sandbox.
When you start using Amazon SNS to send SMS messages, your Amazon Web Services account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your Amazon Web Services account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.
181 |
# File 'sig/client.rbs', line 181
def delete_sms_sandbox_phone_number: (
|
#delete_topic(params = {}) ⇒ Struct
Deletes a topic and all its subscriptions. Deleting a topic might prevent some messages previously sent to the topic from being delivered to subscribers. This action is idempotent, so deleting a topic that does not exist does not result in an error.
187 |
# File 'sig/client.rbs', line 187
def delete_topic: (
|
#get_data_protection_policy(params = {}) ⇒ Types::GetDataProtectionPolicyResponse
Retrieves the specified inline DataProtectionPolicy document that is
stored in the specified Amazon SNS topic.
197 |
# File 'sig/client.rbs', line 197
def get_data_protection_policy: (
|
#get_endpoint_attributes(params = {}) ⇒ Types::GetEndpointAttributesResponse
Retrieves the endpoint attributes for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS. For more information, see Using Amazon SNS Mobile Push Notifications.
207 |
# File 'sig/client.rbs', line 207
def get_endpoint_attributes: (
|
#get_platform_application_attributes(params = {}) ⇒ Types::GetPlatformApplicationAttributesResponse
Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications.
217 |
# File 'sig/client.rbs', line 217
def get_platform_application_attributes: (
|
#get_sms_attributes(params = {}) ⇒ Types::GetSMSAttributesResponse
Returns the settings for sending SMS messages from your Amazon Web Services account.
These settings are set with the SetSMSAttributes action.
227 |
# File 'sig/client.rbs', line 227
def get_sms_attributes: (
|
#get_sms_sandbox_account_status(params = {}) ⇒ Types::GetSMSSandboxAccountStatusResult
Retrieves the SMS sandbox status for the calling Amazon Web Services account in the target Amazon Web Services Region.
When you start using Amazon SNS to send SMS messages, your Amazon Web Services account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your Amazon Web Services account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.
237 |
# File 'sig/client.rbs', line 237
def get_sms_sandbox_account_status: (
|
#get_subscription_attributes(params = {}) ⇒ Types::GetSubscriptionAttributesResponse
Returns all of the properties of a subscription.
246 |
# File 'sig/client.rbs', line 246
def get_subscription_attributes: (
|
#get_topic_attributes(params = {}) ⇒ Types::GetTopicAttributesResponse
Returns all of the properties of a topic. Topic properties returned might differ based on the authorization of the user.
256 |
# File 'sig/client.rbs', line 256
def get_topic_attributes: (
|
#list_endpoints_by_platform_application(params = {}) ⇒ Types::ListEndpointsByPlatformApplicationResponse
Lists the endpoints and endpoint attributes for devices in a supported
push notification service, such as GCM (Firebase Cloud Messaging) and
APNS. The results for ListEndpointsByPlatformApplication are
paginated and return a limited list of endpoints, up to 100. If
additional records are available after the first page results, then a
NextToken string will be returned. To receive the next page, you call
ListEndpointsByPlatformApplication again using the NextToken string
received from the previous call. When there are no more records to
return, NextToken will be null. For more information, see Using
Amazon SNS Mobile Push Notifications.
This action is throttled at 30 transactions per second (TPS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
267 |
# File 'sig/client.rbs', line 267
def list_endpoints_by_platform_application: (
|
#list_origination_numbers(params = {}) ⇒ Types::ListOriginationNumbersResult
Lists the calling Amazon Web Services account's dedicated origination numbers and their metadata. For more information about origination numbers, see Origination numbers in the Amazon SNS Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
279 |
# File 'sig/client.rbs', line 279
def list_origination_numbers: (
|
#list_phone_numbers_opted_out(params = {}) ⇒ Types::ListPhoneNumbersOptedOutResponse
Returns a list of phone numbers that are opted out, meaning you cannot send SMS messages to them.
The results for ListPhoneNumbersOptedOut are paginated, and each
page returns up to 100 phone numbers. If additional phone numbers are
available after the first page of results, then a NextToken string
will be returned. To receive the next page, you call
ListPhoneNumbersOptedOut again using the NextToken string received
from the previous call. When there are no more records to return,
NextToken will be null.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
291 |
# File 'sig/client.rbs', line 291
def list_phone_numbers_opted_out: (
|
#list_platform_applications(params = {}) ⇒ Types::ListPlatformApplicationsResponse
Lists the platform application objects for the supported push
notification services, such as APNS and GCM (Firebase Cloud
Messaging). The results for ListPlatformApplications are paginated
and return a limited list of applications, up to 100. If additional
records are available after the first page results, then a NextToken
string will be returned. To receive the next page, you call
ListPlatformApplications using the NextToken string received from
the previous call. When there are no more records to return,
NextToken will be null. For more information, see Using Amazon SNS
Mobile Push Notifications.
This action is throttled at 15 transactions per second (TPS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
302 |
# File 'sig/client.rbs', line 302
def list_platform_applications: (
|
#list_sms_sandbox_phone_numbers(params = {}) ⇒ Types::ListSMSSandboxPhoneNumbersResult
Lists the calling Amazon Web Services account's current verified and pending destination phone numbers in the SMS sandbox.
When you start using Amazon SNS to send SMS messages, your Amazon Web Services account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your Amazon Web Services account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
313 |
# File 'sig/client.rbs', line 313
def list_sms_sandbox_phone_numbers: (
|
#list_subscriptions(params = {}) ⇒ Types::ListSubscriptionsResponse
Returns a list of the requester's subscriptions. Each call returns a
limited list of subscriptions, up to 100. If there are more
subscriptions, a NextToken is also returned. Use the NextToken
parameter in a new ListSubscriptions call to get further results.
This action is throttled at 30 transactions per second (TPS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
325 |
# File 'sig/client.rbs', line 325
def list_subscriptions: (
|
#list_subscriptions_by_topic(params = {}) ⇒ Types::ListSubscriptionsByTopicResponse
Returns a list of the subscriptions to a specific topic. Each call
returns a limited list of subscriptions, up to 100. If there are more
subscriptions, a NextToken is also returned. Use the NextToken
parameter in a new ListSubscriptionsByTopic call to get further
results.
This action is throttled at 30 transactions per second (TPS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
336 |
# File 'sig/client.rbs', line 336
def list_subscriptions_by_topic: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List all tags added to the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon Simple Notification Service Developer Guide.
347 |
# File 'sig/client.rbs', line 347
def list_tags_for_resource: (
|
#list_topics(params = {}) ⇒ Types::ListTopicsResponse
Returns a list of the requester's topics. Each call returns a limited
list of topics, up to 100. If there are more topics, a NextToken is
also returned. Use the NextToken parameter in a new ListTopics
call to get further results.
This action is throttled at 30 transactions per second (TPS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
358 |
# File 'sig/client.rbs', line 358
def list_topics: (
|
#opt_in_phone_number(params = {}) ⇒ Struct
Use this request to opt in a phone number that is opted out, which enables you to resume sending SMS messages to the number.
You can opt in a phone number only once every 30 days.
367 |
# File 'sig/client.rbs', line 367
def opt_in_phone_number: (
|
#publish(params = {}) ⇒ Types::PublishResponse
Sends a message to an Amazon SNS topic, a text message (SMS message)
directly to a phone number, or a message to a mobile platform endpoint
(when you specify the TargetArn).
If you send a message to a topic, Amazon SNS delivers the message to each endpoint that is subscribed to the topic. The format of the message depends on the notification protocol for each subscribed endpoint.
When a messageId is returned, the message is saved and Amazon SNS
immediately delivers it to subscribers.
To use the Publish action for publishing a message to a mobile
endpoint, such as an app on a Kindle device or mobile phone, you must
specify the EndpointArn for the TargetArn parameter. The EndpointArn
is returned when making a call with the CreatePlatformEndpoint
action.
For more information about formatting messages, see Send Custom Platform-Specific Payloads in Messages to Mobile Devices.
You can publish messages only to topics and endpoints in the same Amazon Web Services Region.
378 |
# File 'sig/client.rbs', line 378
def publish: (
|
#publish_batch(params = {}) ⇒ Types::PublishBatchResponse
Publishes up to 10 messages to the specified topic in a single batch.
This is a batch version of the Publish API. If you try to send more
than 10 messages in a single batch request, you will receive a
TooManyEntriesInBatchRequest exception.
For FIFO topics, multiple messages within a single batch are published in the order they are sent, and messages are deduplicated within the batch and across batches for five minutes.
The result of publishing each message is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.
The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of all of the batched messages) are both 256 KB (262,144 bytes).
The PublishBatch API can send up to 10 messages at a time. If you
attempt to send more than 10 messages in one request, you will
encounter a TooManyEntriesInBatchRequest exception. In such cases,
split your messages into multiple requests, each containing no more
than 10 messages.
Some actions take lists of parameters. These lists are specified using
the param.n notation. Values of n are integers starting from
1. For example, a parameter list with two elements looks like
this:
&AttributeName.1=first
&AttributeName.2=second
If you send a batch message to a topic, Amazon SNS publishes the batch message to each endpoint that is subscribed to the topic. The format of the batch message depends on the notification protocol for each subscribed endpoint.
When a messageId is returned, the batch message is saved, and Amazon
SNS immediately delivers the message to subscribers.
401 |
# File 'sig/client.rbs', line 401
def publish_batch: (
|
#put_data_protection_policy(params = {}) ⇒ Struct
Adds or updates an inline policy document that is stored in the specified Amazon SNS topic.
422 |
# File 'sig/client.rbs', line 422
def put_data_protection_policy: (
|
#remove_permission(params = {}) ⇒ Struct
Removes a statement from a topic's access control policy.
AddPermission, RemovePermission, and
SetTopicAttributes actions in your IAM policy.
429 |
# File 'sig/client.rbs', line 429
def remove_permission: (
|
#set_endpoint_attributes(params = {}) ⇒ Struct
Sets the attributes for an endpoint for a device on one of the supported push notification services, such as GCM (Firebase Cloud Messaging) and APNS. For more information, see Using Amazon SNS Mobile Push Notifications.
436 |
# File 'sig/client.rbs', line 436
def set_endpoint_attributes: (
|
#set_platform_application_attributes(params = {}) ⇒ Struct
Sets the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications. For information on configuring attributes for message delivery status, see Using Amazon SNS Application Attributes for Message Delivery Status.
443 |
# File 'sig/client.rbs', line 443
def set_platform_application_attributes: (
|
#set_sms_attributes(params = {}) ⇒ Struct
Use this request to set the default settings for sending SMS messages and receiving daily SMS usage reports.
You can override some of these settings for a single message when you
use the Publish action with the MessageAttributes.entry.N
parameter. For more information, see Publishing to a mobile phone
in the Amazon SNS Developer Guide.
sns.amazonaws.com) permission to perform the s3:ListBucket
action.
453 |
# File 'sig/client.rbs', line 453
def set_sms_attributes: (
|
#set_subscription_attributes(params = {}) ⇒ Struct
Allows a subscription owner to set an attribute of the subscription to a new value.
459 |
# File 'sig/client.rbs', line 459
def set_subscription_attributes: (
|
#set_topic_attributes(params = {}) ⇒ Struct
Allows a topic owner to set an attribute of the topic to a new value.
AddPermission, RemovePermission, and
SetTopicAttributes actions in your IAM policy.
467 |
# File 'sig/client.rbs', line 467
def set_topic_attributes: (
|
#subscribe(params = {}) ⇒ Types::SubscribeResponse
Subscribes an endpoint to an Amazon SNS topic. If the endpoint type is
HTTP/S or email, or if the endpoint and the topic are not in the same
Amazon Web Services account, the endpoint owner must run the
ConfirmSubscription action to confirm the subscription.
You call the ConfirmSubscription action with the token from the
subscription response. Confirmation tokens are valid for two days.
This action is throttled at 100 transactions per second (TPS).
479 |
# File 'sig/client.rbs', line 479
def subscribe: (
|
#tag_resource(params = {}) ⇒ Struct
Add tags to the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide.
When you use topic tags, keep the following guidelines in mind:
-
Adding more than 50 tags to a topic isn't recommended.
-
Tags don't have any semantic meaning. Amazon SNS interprets tags as character strings.
-
Tags are case-sensitive.
-
A new tag with a key identical to that of an existing tag overwrites the existing tag.
-
Tagging actions are limited to 10 TPS per Amazon Web Services account, per Amazon Web Services Region. If your application requires a higher throughput, file a technical support request.
492 |
# File 'sig/client.rbs', line 492
def tag_resource: (
|
#unsubscribe(params = {}) ⇒ Struct
Deletes a subscription. If the subscription requires authentication
for deletion, only the owner of the subscription or the topic's owner
can unsubscribe, and an Amazon Web Services signature is required. If
the Unsubscribe call does not require authentication and the
requester is not the subscription owner, a final cancellation message
is delivered to the endpoint, so that the endpoint owner can easily
resubscribe to the topic if the Unsubscribe request was unintended.
This action is throttled at 100 transactions per second (TPS).
504 |
# File 'sig/client.rbs', line 504
def unsubscribe: (
|
#untag_resource(params = {}) ⇒ Struct
Remove tags from the specified Amazon SNS topic. For an overview, see Amazon SNS Tags in the Amazon SNS Developer Guide.
513 |
# File 'sig/client.rbs', line 513
def untag_resource: (
|
#verify_sms_sandbox_phone_number(params = {}) ⇒ Struct
Verifies a destination phone number with a one-time password (OTP) for the calling Amazon Web Services account.
When you start using Amazon SNS to send SMS messages, your Amazon Web Services account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your Amazon Web Services account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.
523 |
# File 'sig/client.rbs', line 523
def verify_sms_sandbox_phone_number: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3178 3179 3180 |
# File 'lib/aws-sdk-sns/client.rb', line 3178 def waiter_names [] end |