Method: Aws::SNS::Client#get_platform_application_attributes
- Defined in:
- lib/aws-sdk-sns/client.rb
#get_platform_application_attributes(params = {}) ⇒ Types::GetPlatformApplicationAttributesResponse
Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see [Using Amazon SNS Mobile Push Notifications].
1270 1271 1272 1273 |
# File 'lib/aws-sdk-sns/client.rb', line 1270 def get_platform_application_attributes(params = {}, = {}) req = build_request(:get_platform_application_attributes, params) req.send_request() end |