Class: Aws::SNS::Topic
- Inherits:
-
Object
- Object
- Aws::SNS::Topic
- Extended by:
- Deprecations
- Defined in:
- sig/topic.rbs,
lib/aws-sdk-sns/topic.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #arn ⇒ String
-
#attributes ⇒ Hash<String,String>
A map of the topic's attributes.
Actions collapse
- #add_permission(options = {}) ⇒ EmptyStructure
- #confirm_subscription(options = {}) ⇒ Subscription
- #delete(options = {}) ⇒ EmptyStructure
- #publish(options = {}) ⇒ Types::PublishResponse
- #remove_permission(options = {}) ⇒ EmptyStructure
- #set_attributes(options = {}) ⇒ EmptyStructure
- #subscribe(options = {}) ⇒ Subscription
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #subscriptions(options = {}) ⇒ Subscription::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::GetTopicAttributesResponse
Returns the data for this Topic.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Topic
constructor
A new instance of Topic.
- #load ⇒ self (also: #reload)
Constructor Details
Instance Method Details
#add_permission(options = {}) ⇒ EmptyStructure
37 |
# File 'sig/topic.rbs', line 37
def add_permission: (
|
#arn ⇒ String
18 |
# File 'sig/topic.rbs', line 18
def arn: () -> String
|
#attributes ⇒ Hash<String,String>
A map of the topic's attributes. Attributes in this map include the following:
-
DeliveryPolicy– The JSON serialization of the topic's delivery policy. -
DisplayName– The human-readable name used in theFromfield for notifications toemailandemail-jsonendpoints. -
EffectiveDeliveryPolicy– The JSON serialization of the effective delivery policy, taking system defaults into account. -
Owner– The Amazon Web Services account ID of the topic's owner. -
Policy– The JSON serialization of the topic's access control policy. -
SignatureVersion– The signature version corresponds to the hashing algorithm used while creating the signature of the notifications, subscription confirmations, or unsubscribe confirmation messages sent by Amazon SNS. -
By default,
SignatureVersionis set to 1. The signature is a Base64-encoded SHA1withRSA signature. -
When you set
SignatureVersionto 2. Amazon SNS uses a Base64-encoded SHA256withRSA signature.If the API response does not include the SignatureVersionattribute, it means that theSignatureVersionfor the topic has value 1. -
SubscriptionsConfirmed– The number of confirmed subscriptions for the topic. -
SubscriptionsDeleted– The number of deleted subscriptions for the topic. -
SubscriptionsPending– The number of subscriptions pending confirmation for the topic. -
TopicArn– The topic's ARN. -
TracingConfig– Tracing mode of an Amazon SNS topic. By defaultTracingConfigis set toPassThrough, and the topic passes through the tracing header it receives from an Amazon SNS publisher to its subscriptions. If set toActive, Amazon SNS will vend X-Ray segment data to topic owner account if the sampled flag in the tracing header is true. This is only supported on standard topics.
The following attribute applies only to server-side-encryption:
KmsMasterKeyId- The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see Key Terms. For more examples, see KeyId in the Key Management Service API Reference.
^
The following attributes apply only to FIFO topics:
-
ArchivePolicy– The policy that sets the retention period for messages stored in the message archive of an Amazon SNS FIFO topic. -
BeginningArchiveTime– The earliest starting point at which a message in the topic’s archive can be replayed from. This point in time is based on the configured message retention period set by the topic’s message archiving policy. -
ContentBasedDeduplication– Enables content-based deduplication for FIFO topics. -
By default,
ContentBasedDeduplicationis set tofalse. If you create a FIFO topic and this attribute isfalse, you must specify a value for theMessageDeduplicationIdparameter for the Publish action. -
When you set
ContentBasedDeduplicationtotrue, Amazon SNS uses a SHA-256 hash to generate theMessageDeduplicationIdusing the body of the message (but not the attributes of the message).(Optional) To override the generated value, you can specify a value for the
MessageDeduplicationIdparameter for thePublishaction. -
FifoTopic– When this is set totrue, a FIFO topic is created.
21 |
# File 'sig/topic.rbs', line 21
def attributes: () -> ::Hash[::String, ::String]
|
#confirm_subscription(options = {}) ⇒ Subscription
45 |
# File 'sig/topic.rbs', line 45
def confirm_subscription: (
|
#data ⇒ Types::GetTopicAttributesResponse
Returns the data for this Aws::SNS::Topic. Calls
Client#get_topic_attributes if #data_loaded? is false.
30 |
# File 'sig/topic.rbs', line 30
def data: () -> Types::GetTopicAttributesResponse
|
#data_loaded? ⇒ Boolean
33 |
# File 'sig/topic.rbs', line 33
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
52 |
# File 'sig/topic.rbs', line 52
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
815 816 817 |
# File 'lib/aws-sdk-sns/topic.rb', line 815 def identifiers { arn: @arn } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::SNS::Topic.
Returns self making it possible to chain methods.
topic.reload.data
26 |
# File 'sig/topic.rbs', line 26
def load: () -> self
|
#remove_permission(options = {}) ⇒ EmptyStructure
74 |
# File 'sig/topic.rbs', line 74
def remove_permission: (
|
#set_attributes(options = {}) ⇒ EmptyStructure
80 |
# File 'sig/topic.rbs', line 80
def set_attributes: (
|
#subscriptions(options = {}) ⇒ Subscription::Collection
96 |
# File 'sig/topic.rbs', line 96
def subscriptions: (
|