Class: Aws::SNS::Types::CreateTopicInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::CreateTopicInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
Input for CreateTopic action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A map of attributes with their corresponding values.
-
#data_protection_policy ⇒ String
Amazon SNS message data protection is no longer available to new customers.
-
#name ⇒ String
The name of the topic you want to create.
-
#tags ⇒ Array<Types::Tag>
The list of tags to add to a new topic.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A map of attributes with their corresponding values.
The following lists names, descriptions, and values of the special
request parameters that the CreateTopic action uses:
-
DeliveryPolicy– The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints. -
DisplayName– The display name to use for a topic with SMS,email, andemail-jsonsubscriptions. Foremailandemail-jsonsubscriptions, the display name is used as the sender name for regular notification messages. Subscription confirmation and unsubscribe confirmation emails always use "Amazon Web Services Notifications" as the sender name. -
MaximumMessageSize– The maximum size, in bytes, of a message that can be published to the topic. Valid values are1024to1048576(1 MiB). The default is262144(256 KiB).A topic with a
MaximumMessageSizeabove 256 KiB must have 100 or fewer subscriptions, and each subscription must be an Amazon SQS, Amazon Data Firehose, or Lambda subscription. -
Policy– The policy that defines who can access your topic. By default, only the topic owner can publish or subscribe to the topic. -
TracingConfig– Tracing mode of an Amazon SNS topic. By defaultTracingConfigis set toPassThrough, and the topic passes through the tracing header it receives from an Amazon SNS publisher to its subscriptions. If set toActive, Amazon SNS will vend X-Ray segment data to topic owner account if the sampled flag in the tracing header is true. This is only supported on standard topics. -
HTTP
-
HTTPSuccessFeedbackRoleArn– Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint. -
HTTPSuccessFeedbackSampleRate– Indicates percentage of successful messages to sample for an Amazon SNS topic that is subscribed to an HTTP endpoint. -
HTTPFailureFeedbackRoleArn– Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an HTTP endpoint. -
Amazon Data Firehose
-
FirehoseSuccessFeedbackRoleArn– Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon Data Firehose endpoint. -
FirehoseSuccessFeedbackSampleRate– Indicates percentage of successful messages to sample for an Amazon SNS topic that is subscribed to an Amazon Data Firehose endpoint. -
FirehoseFailureFeedbackRoleArn– Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon Data Firehose endpoint. -
Lambda
-
LambdaSuccessFeedbackRoleArn– Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Lambda endpoint. -
LambdaSuccessFeedbackSampleRate– Indicates percentage of successful messages to sample for an Amazon SNS topic that is subscribed to an Lambda endpoint. -
LambdaFailureFeedbackRoleArn– Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Lambda endpoint. -
Platform application endpoint
-
ApplicationSuccessFeedbackRoleArn– Indicates successful message delivery status for an Amazon SNS topic that is subscribed to a platform application endpoint. -
ApplicationSuccessFeedbackSampleRate– Indicates percentage of successful messages to sample for an Amazon SNS topic that is subscribed to an platform application endpoint. -
ApplicationFailureFeedbackRoleArn– Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an platform application endpoint.In addition to being able to configure topic attributes for message delivery status of notification messages sent to Amazon SNS application endpoints, you can also configure application attributes for the delivery status of push notification messages sent to push notification services.
For example, For more information, see Using Amazon SNS Application Attributes for Message Delivery Status.
-
Amazon SQS
-
SQSSuccessFeedbackRoleArn– Indicates successful message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint. -
SQSSuccessFeedbackSampleRate– Indicates percentage of successful messages to sample for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint. -
SQSFailureFeedbackRoleArn– Indicates failed message delivery status for an Amazon SNS topic that is subscribed to an Amazon SQS endpoint.
The following attribute applies only to server-side encryption:
KmsMasterKeyId– The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see Key Terms. For more examples, see KeyId in the Key Management Service API Reference.
^
The following attributes apply only to FIFO topics:
-
ArchivePolicy– The policy that sets the retention period for messages stored in the message archive of an Amazon SNS FIFO topic. -
ContentBasedDeduplication– Enables content-based deduplication for FIFO topics. -
By default,
ContentBasedDeduplicationis set tofalse. If you create a FIFO topic and this attribute isfalse, you must specify a value for theMessageDeduplicationIdparameter for the Publish action. -
When you set
ContentBasedDeduplicationtotrue, Amazon SNS uses a SHA-256 hash to generate theMessageDeduplicationIdusing the body of the message (but not the attributes of the message).(Optional) To override the generated value, you can specify a value for the
MessageDeduplicationIdparameter for thePublishaction. ^ -
FifoThroughputScope– Enables higher throughput for your FIFO topic by adjusting the scope of deduplication. This attribute has two possible values: -
Topic– The scope of message deduplication is across the entire topic. This is the default value and maintains existing behavior, with a maximum throughput of 3000 messages per second or 20MB per second, whichever comes first. -
MessageGroup– The scope of deduplication is within each individual message group, which enables higher throughput per topic subject to regional quotas. For more information on quotas or to request an increase, see Amazon SNS service quotas in the Amazon Web Services General Reference.
557 558 559 560 561 562 563 564 |
# File 'lib/aws-sdk-sns/types.rb', line 557 class CreateTopicInput < Struct.new( :name, :attributes, :tags, :data_protection_policy) SENSITIVE = [] include Aws::Structure end |
#data_protection_policy ⇒ String
Amazon SNS message data protection is no longer available to new customers. For more information and guidance on alternatives, see Amazon SNS message data protection availability change.
The body of the policy document you want to use for this topic.
You can only add one policy per topic.
The policy must be in JSON string format.
Length Constraints: Maximum length of 30,720.
557 558 559 560 561 562 563 564 |
# File 'lib/aws-sdk-sns/types.rb', line 557 class CreateTopicInput < Struct.new( :name, :attributes, :tags, :data_protection_policy) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the topic you want to create.
Constraints: Topic names must be made up of only uppercase and lowercase ASCII letters, numbers, underscores, and hyphens, and must be between 1 and 256 characters long.
For a FIFO (first-in-first-out) topic, the name must end with the
.fifo suffix.
557 558 559 560 561 562 563 564 |
# File 'lib/aws-sdk-sns/types.rb', line 557 class CreateTopicInput < Struct.new( :name, :attributes, :tags, :data_protection_policy) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags to add to a new topic.
sns:CreateTopic and sns:TagResource permissions.
557 558 559 560 561 562 563 564 |
# File 'lib/aws-sdk-sns/types.rb', line 557 class CreateTopicInput < Struct.new( :name, :attributes, :tags, :data_protection_policy) SENSITIVE = [] include Aws::Structure end |