Class: Aws::SNS::Types::FilterPolicyLimitExceededException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sns/types.rb

Overview

Indicates that the number of filter polices in your Amazon Web Services account exceeds the limit. To add more filter polices, submit an Amazon SNS Limit Increase case in the Amazon Web ServicesSupport Center.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


672
673
674
675
676
# File 'lib/aws-sdk-sns/types.rb', line 672

class FilterPolicyLimitExceededException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end