Class: Aws::SNS::Types::GetSMSAttributesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::GetSMSAttributesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
The input for the GetSMSAttributes request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
A list of the individual attribute names, such as
MonthlySpendLimit, for which you want values.
Instance Attribute Details
#attributes ⇒ Array<String>
A list of the individual attribute names, such as
MonthlySpendLimit, for which you want values.
For all attribute names, see SetSMSAttributes.
If you don't use this parameter, Amazon SNS returns all SMS attributes.
850 851 852 853 854 |
# File 'lib/aws-sdk-sns/types.rb', line 850 class GetSMSAttributesInput < Struct.new( :attributes) SENSITIVE = [] include Aws::Structure end |