Class: Aws::SNS::Types::KMSInvalidStateException
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::KMSInvalidStateException
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
The request was rejected because the state of the specified resource isn't valid for this request. For more information, see Key states of Amazon Web Services KMS keys in the Key Management Service Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-sns/types.rb', line 1242 class KMSInvalidStateException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |