Class: Aws::SNS::Types::ListEndpointsByPlatformApplicationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::ListEndpointsByPlatformApplicationInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
Input for ListEndpointsByPlatformApplication action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
NextTokenstring is used when callingListEndpointsByPlatformApplicationaction to retrieve additional records that are available after the first page results. -
#platform_application_arn ⇒ String
PlatformApplicationArnforListEndpointsByPlatformApplicationInputaction.
Instance Attribute Details
#next_token ⇒ String
NextToken string is used when calling ListEndpointsByPlatformApplication action to retrieve additional records that are available after the first page results.
1282 1283 1284 1285 1286 1287 |
# File 'lib/aws-sdk-sns/types.rb', line 1282 class ListEndpointsByPlatformApplicationInput < Struct.new( :platform_application_arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#platform_application_arn ⇒ String
PlatformApplicationArn for ListEndpointsByPlatformApplicationInput action.
1282 1283 1284 1285 1286 1287 |
# File 'lib/aws-sdk-sns/types.rb', line 1282 class ListEndpointsByPlatformApplicationInput < Struct.new( :platform_application_arn, :next_token) SENSITIVE = [] include Aws::Structure end |