Class: Aws::SNS::Types::ListPhoneNumbersOptedOutInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::ListPhoneNumbersOptedOutInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
The input for the ListPhoneNumbersOptedOut action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A
NextTokenstring is used when you call theListPhoneNumbersOptedOutaction to retrieve additional records that are available after the first page of results.
Instance Attribute Details
#next_token ⇒ String
A NextToken string is used when you call the
ListPhoneNumbersOptedOut action to retrieve additional records
that are available after the first page of results.
1385 1386 1387 1388 1389 |
# File 'lib/aws-sdk-sns/types.rb', line 1385 class ListPhoneNumbersOptedOutInput < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |