Class: Aws::SNS::Types::ListPhoneNumbersOptedOutResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::ListPhoneNumbersOptedOutResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
The response from the ListPhoneNumbersOptedOut action.
Constant Summary collapse
- SENSITIVE =
[:phone_numbers]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A
NextTokenstring is returned when you call theListPhoneNumbersOptedOutaction if additional records are available after the first page of results. -
#phone_numbers ⇒ Array<String>
A list of phone numbers that are opted out of receiving SMS messages.
Instance Attribute Details
#next_token ⇒ String
A NextToken string is returned when you call the
ListPhoneNumbersOptedOut action if additional records are
available after the first page of results.
1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-sns/types.rb', line 1407 class ListPhoneNumbersOptedOutResponse < Struct.new( :phone_numbers, :next_token) SENSITIVE = [:phone_numbers] include Aws::Structure end |
#phone_numbers ⇒ Array<String>
A list of phone numbers that are opted out of receiving SMS messages. The list is paginated, and each page can contain up to 100 phone numbers.
1407 1408 1409 1410 1411 1412 |
# File 'lib/aws-sdk-sns/types.rb', line 1407 class ListPhoneNumbersOptedOutResponse < Struct.new( :phone_numbers, :next_token) SENSITIVE = [:phone_numbers] include Aws::Structure end |