Class: Aws::SNS::Types::MessageAttributeValue

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sns/types.rb

Overview

The user-specified message attribute value. For string data types, the value attribute has the same restrictions on the content as the message body. For more information, see Publish.

Name, type, and value must not be empty or null. In addition, the message body should not be empty or null. All parts of the message attribute, including name, type, and value, are included in the message size restriction, which is 256 KiB (262,144 bytes) by default and is determined by the topic's MaximumMessageSize attribute. For more information, see Large message payloads, Amazon SNS message attributes and Publishing to a mobile phone in the Amazon SNS Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#binary_valueString

Binary type attributes can store any binary data, for example, compressed data, encrypted data, or images.

Returns:



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-sns/types.rb', line 1665

class MessageAttributeValue < Struct.new(
  :data_type,
  :string_value,
  :binary_value)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

Amazon SNS supports the following logical data types: String, String.Array, Number, and Binary. For more information, see Message Attribute Data Types.

Returns:



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-sns/types.rb', line 1665

class MessageAttributeValue < Struct.new(
  :data_type,
  :string_value,
  :binary_value)
  SENSITIVE = []
  include Aws::Structure
end

#string_valueString

Strings are Unicode with UTF8 binary encoding. For a list of code values, see ASCII Printable Characters.

Returns:



1665
1666
1667
1668
1669
1670
1671
# File 'lib/aws-sdk-sns/types.rb', line 1665

class MessageAttributeValue < Struct.new(
  :data_type,
  :string_value,
  :binary_value)
  SENSITIVE = []
  include Aws::Structure
end