Class: Aws::SNS::Types::SetEndpointAttributesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::SetEndpointAttributesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
Input for SetEndpointAttributes action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
A map of the endpoint attributes.
-
#endpoint_arn ⇒ String
EndpointArn used for
SetEndpointAttributesaction.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
A map of the endpoint attributes. Attributes in this map include the following:
-
CustomUserData– arbitrary user data to associate with the endpoint. Amazon SNS does not use this data. The data must be in UTF-8 format and less than 2KB. -
Enabled– flag that enables/disables delivery to the endpoint. Amazon SNS will set this to false when a notification service indicates to Amazon SNS that the endpoint is invalid. Users can set it back to true, typically after updating Token. -
Token– device token, also referred to as a registration id, for an app and mobile device. This is returned from the notification service when an app and mobile device are registered with the notification service.
2391 2392 2393 2394 2395 2396 |
# File 'lib/aws-sdk-sns/types.rb', line 2391 class SetEndpointAttributesInput < Struct.new( :endpoint_arn, :attributes) SENSITIVE = [] include Aws::Structure end |
#endpoint_arn ⇒ String
EndpointArn used for SetEndpointAttributes action.
2391 2392 2393 2394 2395 2396 |
# File 'lib/aws-sdk-sns/types.rb', line 2391 class SetEndpointAttributesInput < Struct.new( :endpoint_arn, :attributes) SENSITIVE = [] include Aws::Structure end |