Class: Aws::SNS::Subscription

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/subscription.rbs,
lib/aws-sdk-sns/subscription.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(arn, options = {}) ⇒ Subscription #initialize(options = {}) ⇒ Subscription

Returns a new instance of Subscription.

Overloads:

  • #initialize(arn, options = {}) ⇒ Subscription

    Parameters:

    • arn (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Subscription

    Options Hash (options):

    • :arn (required, String)
    • :client (Client)


13
14
15
# File 'sig/subscription.rbs', line 13

def initialize: (String arn, Hash[Symbol, untyped] options) -> void
| (arn: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#arnString

Returns:

  • (String)


18
# File 'sig/subscription.rbs', line 18

def arn: () -> String

#attributesHash<String,String>

A map of the subscription's attributes. Attributes in this map include the following:

  • ConfirmationWasAuthenticatedtrue if the subscription confirmation request was authenticated.

  • DeliveryPolicy – The JSON serialization of the subscription's delivery policy.

  • EffectiveDeliveryPolicy – The JSON serialization of the effective delivery policy that takes into account the topic delivery policy and account system defaults.

  • FilterPolicy – The filter policy JSON that is assigned to the subscription. For more information, see Amazon SNS Message Filtering in the Amazon SNS Developer Guide.

  • FilterPolicyScope – This attribute lets you choose the filtering scope by using one of the following string value types:

  • MessageAttributes (default) – The filter is applied on the message attributes.

  • MessageBody – The filter is applied on the message body.

  • Owner – The Amazon Web Services account ID of the subscription's owner.

  • PendingConfirmationtrue if the subscription hasn't been confirmed. To confirm a pending subscription, call the ConfirmSubscription action with a confirmation token.

  • RawMessageDeliverytrue if raw message delivery is enabled for the subscription. Raw messages are free of JSON formatting and can be sent to HTTP/S and Amazon SQS endpoints.

  • RedrivePolicy – When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing.

  • SubscriptionArn – The subscription's ARN.

  • TopicArn – The topic ARN that the subscription is associated with.

The following attribute applies only to Amazon Data Firehose delivery stream subscriptions:

  • SubscriptionRoleArn – The ARN of the IAM role that has the following:

  • Permission to write to the Firehose delivery stream

  • Amazon SNS listed as a trusted entity Specifying a valid ARN for this attribute is required for Firehose delivery stream subscriptions. For more information, see Fanout to Firehose delivery streams in the Amazon SNS Developer Guide.

Returns:

  • (Hash<String,String>)


21
# File 'sig/subscription.rbs', line 21

def attributes: () -> ::Hash[::String, ::String]

#clientClient

Returns:



108
# File 'lib/aws-sdk-sns/subscription.rb', line 108

def client: () -> Client

#dataTypes::GetSubscriptionAttributesResponse

Returns the data for this Aws::SNS::Subscription. Calls Client#get_subscription_attributes if #data_loaded? is false.



30
# File 'sig/subscription.rbs', line 30

def data: () -> Types::GetSubscriptionAttributesResponse

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



33
# File 'sig/subscription.rbs', line 33

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


subscription.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


37
# File 'sig/subscription.rbs', line 37

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


225
226
227
# File 'lib/aws-sdk-sns/subscription.rb', line 225

def identifiers
  { arn: @arn }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::SNS::Subscription. Returns self making it possible to chain methods.

subscription.reload.data

Returns:

  • (self)


26
# File 'sig/subscription.rbs', line 26

def load: () -> self

#set_attributes(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


subscription.set_attributes({
  attribute_name: "attributeName", # required
  attribute_value: "attributeValue",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :attribute_name (required, String)

    A map of attributes with their corresponding values.

    The following lists the names, descriptions, and values of the special request parameters that this action uses:

    • DeliveryPolicy – The policy that defines how Amazon SNS retries failed deliveries to HTTP/S endpoints.

    • FilterPolicy – The simple JSON object that lets your subscriber receive only a subset of messages, rather than receiving every message published to the topic.

    • FilterPolicyScope – This attribute lets you choose the filtering scope by using one of the following string value types:

    • MessageAttributes (default) – The filter is applied on the message attributes.

    • MessageBody – The filter is applied on the message body.

    • RawMessageDelivery – When set to true, enables raw message delivery to Amazon SQS or HTTP/S endpoints. This eliminates the need for the endpoints to process JSON formatting, which is otherwise created for Amazon SNS metadata.

    • RedrivePolicy – When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing.

    The following attribute applies only to Amazon Data Firehose delivery stream subscriptions:

    • SubscriptionRoleArn – The ARN of the IAM role that has the following:

    • Permission to write to the Firehose delivery stream

    • Amazon SNS listed as a trusted entity Specifying a valid ARN for this attribute is required for Firehose delivery stream subscriptions. For more information, see Fanout to Firehose delivery streams in the Amazon SNS Developer Guide.

  • :attribute_value (String)

    The new value for the attribute in JSON format.

Returns:

  • (EmptyStructure)


42
# File 'sig/subscription.rbs', line 42

def set_attributes: (