Class: Aws::SNS::Subscription
- Inherits:
-
Object
- Object
- Aws::SNS::Subscription
- Extended by:
- Deprecations
- Defined in:
- sig/subscription.rbs,
lib/aws-sdk-sns/subscription.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
- #arn ⇒ String
-
#attributes ⇒ Hash<String,String>
A map of the subscription's attributes.
Actions collapse
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #set_attributes(options = {}) ⇒ EmptyStructure
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::GetSubscriptionAttributesResponse
Returns the data for this Subscription.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Subscription
constructor
A new instance of Subscription.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current Subscription.
Constructor Details
#initialize(arn, options = {}) ⇒ Subscription #initialize(options = {}) ⇒ Subscription
Returns a new instance of Subscription.
13 14 15 |
# File 'sig/subscription.rbs', line 13
def initialize: (String arn, Hash[Symbol, untyped] options) -> void
| (arn: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#arn ⇒ String
18 |
# File 'sig/subscription.rbs', line 18
def arn: () -> String
|
#attributes ⇒ Hash<String,String>
A map of the subscription's attributes. Attributes in this map include the following:
-
ConfirmationWasAuthenticated–trueif the subscription confirmation request was authenticated. -
DeliveryPolicy– The JSON serialization of the subscription's delivery policy. -
EffectiveDeliveryPolicy– The JSON serialization of the effective delivery policy that takes into account the topic delivery policy and account system defaults. -
FilterPolicy– The filter policy JSON that is assigned to the subscription. For more information, see Amazon SNS Message Filtering in the Amazon SNS Developer Guide. -
FilterPolicyScope– This attribute lets you choose the filtering scope by using one of the following string value types: -
MessageAttributes(default) – The filter is applied on the message attributes. -
MessageBody– The filter is applied on the message body. -
Owner– The Amazon Web Services account ID of the subscription's owner. -
PendingConfirmation–trueif the subscription hasn't been confirmed. To confirm a pending subscription, call theConfirmSubscriptionaction with a confirmation token. -
RawMessageDelivery–trueif raw message delivery is enabled for the subscription. Raw messages are free of JSON formatting and can be sent to HTTP/S and Amazon SQS endpoints. -
RedrivePolicy– When specified, sends undeliverable messages to the specified Amazon SQS dead-letter queue. Messages that can't be delivered due to client errors (for example, when the subscribed endpoint is unreachable) or server errors (for example, when the service that powers the subscribed endpoint becomes unavailable) are held in the dead-letter queue for further analysis or reprocessing. -
SubscriptionArn– The subscription's ARN. -
TopicArn– The topic ARN that the subscription is associated with.
The following attribute applies only to Amazon Data Firehose delivery stream subscriptions:
-
SubscriptionRoleArn– The ARN of the IAM role that has the following: -
Permission to write to the Firehose delivery stream
-
Amazon SNS listed as a trusted entity Specifying a valid ARN for this attribute is required for Firehose delivery stream subscriptions. For more information, see Fanout to Firehose delivery streams in the Amazon SNS Developer Guide.
21 |
# File 'sig/subscription.rbs', line 21
def attributes: () -> ::Hash[::String, ::String]
|
#data ⇒ Types::GetSubscriptionAttributesResponse
Returns the data for this Aws::SNS::Subscription. Calls
Client#get_subscription_attributes if #data_loaded? is false.
30 |
# File 'sig/subscription.rbs', line 30
def data: () -> Types::GetSubscriptionAttributesResponse
|
#data_loaded? ⇒ Boolean
33 |
# File 'sig/subscription.rbs', line 33
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
37 |
# File 'sig/subscription.rbs', line 37
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
225 226 227 |
# File 'lib/aws-sdk-sns/subscription.rb', line 225 def identifiers { arn: @arn } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::SNS::Subscription.
Returns self making it possible to chain methods.
subscription.reload.data
26 |
# File 'sig/subscription.rbs', line 26
def load: () -> self
|
#set_attributes(options = {}) ⇒ EmptyStructure
42 |
# File 'sig/subscription.rbs', line 42
def set_attributes: (
|