Class: Aws::SNS::Types::SetEndpointAttributesInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sns/types.rb

Overview

Input for SetEndpointAttributes action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

A map of the endpoint attributes. Attributes in this map include the following:

  • CustomUserData – arbitrary user data to associate with the endpoint. Amazon SNS does not use this data. The data must be in UTF-8 format and less than 2KB.

  • Enabled – flag that enables/disables delivery to the endpoint. Amazon SNS will set this to false when a notification service indicates to Amazon SNS that the endpoint is invalid. Users can set it back to true, typically after updating Token.

  • Token – device token, also referred to as a registration id, for an app and mobile device. This is returned from the notification service when an app and mobile device are registered with the notification service.



2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-sns/types.rb', line 2347

class SetEndpointAttributesInput < Struct.new(
  :endpoint_arn,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_arnString

EndpointArn used for SetEndpointAttributes action.



2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-sns/types.rb', line 2347

class SetEndpointAttributesInput < Struct.new(
  :endpoint_arn,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end