Class: Aws::SNS::Types::SubscribeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SNS::Types::SubscribeResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sns/types.rb
Overview
Response for Subscribe action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#subscription_arn ⇒ String
The ARN of the subscription if it is confirmed, or the string "pending confirmation" if the subscription requires confirmation.
Instance Attribute Details
#subscription_arn ⇒ String
The ARN of the subscription if it is confirmed, or the string
"pending confirmation" if the subscription requires confirmation.
However, if the API request parameter ReturnSubscriptionArn is
true, then the value is always the subscription ARN, even if the
subscription requires confirmation.
3067 3068 3069 3070 3071 |
# File 'lib/aws-sdk-sns/types.rb', line 3067 class SubscribeResponse < Struct.new( :subscription_arn) SENSITIVE = [] include Aws::Structure end |